| Home | Libraries | People | FAQ | More

### is_polymorphic

    template <class T>
    struct is_polymorphic : public true_type-or-false_type {};

Inherits: If T is a (possibly cv-qualified) polymorphic type then inherits from true_type, otherwise inherits from false_type. Type `T` must be a complete type.

C++ Standard Reference: 10.3.

Compiler Compatibility: The implementation requires some knowledge of the compilers ABI, it does actually seem to work with the majority of compilers though.

Header: `#include <boost/type_traits/is_polymorphic.hpp>` or `#include <boost/type_traits.hpp>`

Examples:

> Given: `class poly{ virtual ~poly(); };`

> `is_polymorphic<poly>` inherits from `true_type`.

> `is_polymorphic<poly const>::type` is the type `true_type`.

> `is_polymorphic<poly>::value` is an integral constant expression that evaluates to true.

> `is_polymorphic<T>::value_type` is the type `bool`.